==> jc-1.4.0.tar.gz: polyglot/types/reflect/Method.h <==
// class polyglot.types.reflect.Method

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 78cd51360123a1f9 polyglot_types_reflect_Method

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_Method_H_
#define _JC_polyglot_types_reflect_Method_H_

// Forward structure declarations
struct _jc_java_io_DataInputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_ConstructorInstance$object;
struct _jc_polyglot_types_MethodInstance$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_types_reflect_ClassFile$object;
struct _jc_polyglot_types_reflect_Exceptions$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_Method$sub_refs	_jc_polyglot_types_reflect_Method$sub_refs;
typedef struct _jc_polyglot_types_reflect_Method$sub_nonrefs	_jc_polyglot_types_reflect_Method$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_Method$refs	_jc_polyglot_types_reflect_Method$refs;
typedef struct _jc_polyglot_types_reflect_Method$nonrefs	_jc_polyglot_types_reflect_Method$nonrefs;
typedef struct _jc_polyglot_types_reflect_Method$object	_jc_polyglot_types_reflect_Method$object;

typedef const struct _jc_polyglot_types_reflect_Method$vmethods	_jc_polyglot_types_reflect_Method$vmethods;
typedef const struct _jc_polyglot_types_reflect_Method$vtable	_jc_polyglot_types_reflect_Method$vtable;
typedef const struct _jc_polyglot_types_reflect_Method$vtype	_jc_polyglot_types_reflect_Method$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_Method$method$_init$b1ea5c53786ab2c1(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_java_io_DataInputStream$object *, struct _jc_polyglot_types_reflect_ClassFile$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_reflect_Method$method$constructorInstance$dc6da5893b14e49d(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_types_reflect_Method$method$methodInstance$229af93934f7bca6(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_types_reflect_Method$method$name$e6acce026cadf81e(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_reflect_Method$method_info$constructorInstance$dc6da5893b14e49d;
extern _jc_method _jc_polyglot_types_reflect_Method$method_info$methodInstance$229af93934f7bca6;
extern _jc_method _jc_polyglot_types_reflect_Method$method_info$name$e6acce026cadf81e;

// Virtual methods structure
struct _jc_polyglot_types_reflect_Method$vmethods {
	struct _jc_object	*(*constructorInstance$dc6da5893b14e49d)(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_object	*(*methodInstance$229af93934f7bca6)(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*name$e6acce026cadf81e)(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *);
};

// Vtable
struct _jc_polyglot_types_reflect_Method$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Method$vmethods	polyglot_types_reflect_Method;
};

// Vtype
struct _jc_polyglot_types_reflect_Method$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_Method$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Method$sub_refs {
	struct _jc_polyglot_types_reflect_ClassFile$object	*clazz;
	_jc_object_array	*attrs;
	struct _jc_polyglot_types_reflect_Exceptions$object	*exceptions;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_Method$refs {
    _jc_polyglot_types_reflect_Method$sub_refs	polyglot_types_reflect_Method;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Method$sub_nonrefs {
	jint	modifiers;
	jint	name;
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_Method$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Method$sub_nonrefs	polyglot_types_reflect_Method;
};

// Object instance structure
struct _jc_polyglot_types_reflect_Method$object {
	_jc_polyglot_types_reflect_Method$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_Method$vtype	*vtype;
	_jc_polyglot_types_reflect_Method$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_Method$vtype _jc_polyglot_types_reflect_Method$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_Method, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_Method$class_object;

#endif	/* _JC_polyglot_types_reflect_Method_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/Method.h <==
// class polyglot.types.reflect.Method

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 78cd51360123a1f9 polyglot_types_reflect_Method

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_Method_H_
#define _JC_polyglot_types_reflect_Method_H_

// Forward structure declarations
struct _jc_java_io_DataInputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_ConstructorInstance$object;
struct _jc_polyglot_types_MethodInstance$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_types_reflect_ClassFile$object;
struct _jc_polyglot_types_reflect_Exceptions$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_Method$sub_refs	_jc_polyglot_types_reflect_Method$sub_refs;
typedef struct _jc_polyglot_types_reflect_Method$sub_nonrefs	_jc_polyglot_types_reflect_Method$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_Method$refs	_jc_polyglot_types_reflect_Method$refs;
typedef struct _jc_polyglot_types_reflect_Method$nonrefs	_jc_polyglot_types_reflect_Method$nonrefs;
typedef struct _jc_polyglot_types_reflect_Method$object	_jc_polyglot_types_reflect_Method$object;

typedef const struct _jc_polyglot_types_reflect_Method$vmethods	_jc_polyglot_types_reflect_Method$vmethods;
typedef const struct _jc_polyglot_types_reflect_Method$vtable	_jc_polyglot_types_reflect_Method$vtable;
typedef const struct _jc_polyglot_types_reflect_Method$vtype	_jc_polyglot_types_reflect_Method$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_Method$method$_init$b1ea5c53786ab2c1(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_java_io_DataInputStream$object *, struct _jc_polyglot_types_reflect_ClassFile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_reflect_Method$method$constructorInstance$dc6da5893b14e49d(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_reflect_Method$method$methodInstance$229af93934f7bca6(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_types_reflect_Method$method$name$e6acce026cadf81e(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_reflect_Method$method_info$constructorInstance$dc6da5893b14e49d;
extern _jc_method _jc_polyglot_types_reflect_Method$method_info$methodInstance$229af93934f7bca6;
extern _jc_method _jc_polyglot_types_reflect_Method$method_info$name$e6acce026cadf81e;

// Virtual methods structure
struct _jc_polyglot_types_reflect_Method$vmethods {
	struct _jc_object	*(*constructorInstance$dc6da5893b14e49d)(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*methodInstance$229af93934f7bca6)(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*name$e6acce026cadf81e)(_jc_env *, struct _jc_polyglot_types_reflect_Method$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_reflect_Method$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Method$vmethods	polyglot_types_reflect_Method;
};

// Vtype
struct _jc_polyglot_types_reflect_Method$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_Method$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Method$sub_refs {
	struct _jc_polyglot_types_reflect_ClassFile$object	*clazz;
	_jc_object_array	*attrs;
	struct _jc_polyglot_types_reflect_Exceptions$object	*exceptions;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_Method$refs {
    _jc_polyglot_types_reflect_Method$sub_refs	polyglot_types_reflect_Method;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Method$sub_nonrefs {
	jint	modifiers;
	jint	name;
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_Method$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Method$sub_nonrefs	polyglot_types_reflect_Method;
};

// Object instance structure
struct _jc_polyglot_types_reflect_Method$object {
	_jc_polyglot_types_reflect_Method$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_Method$vtype	*vtype;
	_jc_polyglot_types_reflect_Method$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_Method$vtype _jc_polyglot_types_reflect_Method$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_Method, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_Method$class_object;

#endif	/* _JC_polyglot_types_reflect_Method_H_ */
